import click

import kumparanian.ds as ds


@click.group()
def cli():
    pass


ds_help_text = """For data Scientist role.

Before you submit your trained model, you can verify your trained model using
the following command:

$ kumparanian ds verify YOURMODEL.pickle

Use the following command to evaluate your trained model against your test
dataset:

$ kumparanian ds evaluate --model YOURMODEL.pickle --test-set file.csv

If you found any issues, feel free report it at:
https://github.com/kumparan/kumparanian/issues

"""


@cli.group(name="ds", help=ds_help_text)
def ds_group():
    pass


@ds_group.command(help="Verify the model")
@click.argument("model", type=click.Path(exists=True))
def verify(model):
    try:
        ds.model.verify(model)
    except Exception as err:
        message = "[INVALID] {}".format(err)
        click.secho(message, fg="red")
        exit(1)
    click.secho("[VALID] Model is valid.", fg="green")
    exit(0)


@ds_group.command(help="Evaluate the model")
@click.option("--model",
              required=True,
              type=click.Path(exists=True),
              help="Path to model pickle file")
@click.option("--test",
              required=True,
              type=click.Path(exists=True),
              help="Path test set CSV file")
def evaluate():
    click.echo("test")


def main():
    cli()



from setuptools import setup

# Package details
setup(
    name="kumparanian",
    version="0.0.2",
    entry_points={
        "console_scripts": ["kumparanian = kumparanian.cli:main"]
    },
    author="Bayu Aldi Yansyah",
    author_email="bayualdiyansyah@gmail.com",
    url="https://github.com/kumparan/kumparanian",
    description="Kumparanian CLI",
    long_description=open("README.rst", "r").read(),
    license="BSD 3-Clause License",
    packages=["kumparanian"],
    install_requires=[
        "click==6.7",
        "colorama==0.3.9",
        "dill==0.2.7.1"
    ],
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5"
    ]
)
